pub struct CliRunner { /* private fields */ }Expand description
Executes CLI commands.
Provides utilities for running a cli command to completion.
Implementations
Sourceimpl CliRunner
impl CliRunner
Sourcepub fn try_default_runtime() -> Result<Self, RuntimeBuildError>
pub fn try_default_runtime() -> Result<Self, RuntimeBuildError>
Sourcepub fn try_with_runtime_config(
config: RuntimeConfig,
) -> Result<Self, RuntimeBuildError>
pub fn try_with_runtime_config( config: RuntimeConfig, ) -> Result<Self, RuntimeBuildError>
Creates a new CliRunner with the given RuntimeConfig.
Sourcepub const fn with_config(self, config: CliRunnerConfig) -> Self
pub const fn with_config(self, config: CliRunnerConfig) -> Self
Sets the CliRunnerConfig for this runner.
Sourcepub fn block_on<F, T>(&self, fut: F) -> Twhere
F: Future<Output = T>,
pub fn block_on<F, T>(&self, fut: F) -> Twhere
F: Future<Output = T>,
Executes an async block on the runtime and blocks until completion.
Sourcepub fn run_command_until_exit<F, E>(
self,
command: impl FnOnce(CliContext) -> F,
) -> Result<(), E>
pub fn run_command_until_exit<F, E>( self, command: impl FnOnce(CliContext) -> F, ) -> Result<(), E>
Executes the given async command on the tokio runtime until the command future resolves or
until the process receives a SIGINT or SIGTERM signal.
Tasks spawned by the command via the [TaskExecutor] are shut down and an attempt is made
to drive their shutdown to completion after the command has finished.
Sourcepub fn run_blocking_command_until_exit<F, E>(
self,
command: impl FnOnce(CliContext) -> F + Send + 'static,
) -> Result<(), E>
pub fn run_blocking_command_until_exit<F, E>( self, command: impl FnOnce(CliContext) -> F + Send + 'static, ) -> Result<(), E>
Executes a command in a blocking context with access to CliContext.
Sourcepub fn run_until_ctrl_c<F, E>(self, fut: F) -> Result<(), E>
pub fn run_until_ctrl_c<F, E>(self, fut: F) -> Result<(), E>
Executes a regular future until completion or until external signal received.
Sourcepub fn run_blocking_until_ctrl_c<F, E>(self, fut: F) -> Result<(), E>
pub fn run_blocking_until_ctrl_c<F, E>(self, fut: F) -> Result<(), E>
Executes a regular future as a spawned blocking task until completion or until external signal received.